@@ -5,8 +5,9 @@ import yaml
 import importlib
 import logging
 import tornado.process
-from collections import Mapping
 from optparse import OptionParser
+from tornado import netutil
+from tornado.httpserver import HTTPServer
 
 
 class Object(object):
@@ -103,7 +104,7 @@ class Service(Object):
     :ivar config: parsed ``yaml`` config file, ``dict``
     """
 
-    #: Required command line arguments
+    # : Required command line arguments
     required_options = ["config"]
 
     def init(self, **kwargs):
@@ -209,6 +210,52 @@ class MultiProcService(Service):
         tornado.process.fork_processes(self.config["num_processes"])
 
 
+class SocketService(MultiProcService):
+    def init_sockets(self):
+        raise NotImplementedError
+
+    def init_socket_server(self, io_loop=None, ssl_options=None):
+        raise NotImplementedError
+
+    def run(self, io_loop=None):
+        MultiProcService.run(self)
+
+        self.init_sockets()
+        self.init_socket_server(io_loop=io_loop)
+
+        self.socket_server.start(num_processes=self.config["num_processes"])
+        self.socket_server.add_sockets(self.sockets)
+
+        from tornado.ioloop import IOLoop
+        IOLoop.instance().start()
+
+    def stop(self):
+        from tornado.ioloop import IOLoop
+
+        self.socket_server.stop()
+        IOLoop.instance().stop()
+
+
+class TCPSocketService(SocketService):
+    def init_sockets(self):
+        self.sockets = netutil.bind_sockets(
+            self.config["port"], self.config["address"])
+
+
+class UNIXSocketService(SocketService):
+    def init_sockets(self):
+        self.sockets = [netutil.bind_unix_socket(self.config["socket_path"])]
+
+
+class HTTPService(TCPSocketService):
+
+    def init(self, application, **kwargs):
+        self.application = application
+
+    def init_socket_server(self, io_loop=None):
+        self.socket_server = HTTPServer(self.application, io_loop=io_loop)
+
+
 class Error(Exception):
     def __init__(self, message):
         Exception.__init__(self)
